from .functions import Functions
from .user import User

class Typergame:

    def __init__(self, projectname: str, commands: list, defaultdelay: int = 0.02, defaultnewline: bool = True):

        self.functions = Functions(defaultdelay, defaultnewline)
        self.user = User(projectname, commands, defaultdelay, defaultnewline)




import os, sys, time

class Functions:

    def __init__(self, defaultdelay: int, defaultnewline: bool):

        self.defaultdelay = defaultdelay
        self.defaultnewline = defaultnewline

    def clear(self):

        if os.name == "nt":
            os.system("cls")
        else:
            os.system("clear")

    def pause(self, delay: str):

        time.sleep(delay)

    def write(self, text: str, delay: int = None, newline: bool = None):

        if delay == None:
            runningdelay = self.defaultdelay
        else:
            runningdelay = delay
        if newline == None:
            runningnewline = self.defaultnewline
        else:
            runningnewline = newline
        for char in text:
            sys.stdout.write(char)
            sys.stdout.flush()
            self.pause(runningdelay)
        if runningnewline:
            print()

    def ask(self, question: str, delay: int = None):

        self.write(question, delay, True)
        return input("> ")




from setuptools import setup, find_packages

from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name = 'typergame',
    packages = find_packages(),
    version = '0.2.3',
    description = 'A library to easily set up typergames.',
    author = 'drooler',
    long_description = long_description,
    long_description_content_type='text/markdown'
)




from .functions import Functions

class User:

    def __init__(self, projectname: str, commands: list, defaultdelay: int, defaultnewline: bool):
        
        self.functions = Functions(defaultdelay, defaultnewline)
        self.projectname = projectname
        runningcommands = []
        for command in commands:
            runningcommands.append(command.lower())
        self.commands = runningcommands
        self.functions.clear()
        self.functions.write(f"Welcome to {self.projectname}")
        self.username = self.functions.ask("Choose a username")
        self.stats = {}
        self.functions.clear()

    def addstats(self, stat: str):

        self.stats[stat.lower()] = 0

    def updatestats(self, stat: str, value: int):

        self.stats[stat.lower()] += value

    def run(self):

        command = self.functions.ask(f"Commands: {', '.join(self.commands)}")
        self.functions.clear()
        if command.lower() in self.commands:
            return command.lower()
        else:
            self.functions.write("That is not a valid option")
            self.functions.clear()
            return
          
    def __str__(self):

        runningstats = ""
        for stat in list(self.stats.keys()):
            runningstats += f"{stat.lower()}: {self.stats[stat]}\n"
        return f"{self.username}\n{(len(self.username) + 1) * '-'}\n{runningstats}"
    
